def validate_schema(data, schema):
    """
    Validate data against a JSON schema.
    """
    pass


def validate_mdp(data):
    """
    Validate a Myreze Data Package against the MDP schema.
    """
    pass
